@@ -25,8 +25,8 @@ class Plan(NamespacedResource, MTV):
 
     def __init__(
         self,
-        name,
-        namespace,
+        name=None,
+        namespace=None,
         source_provider_name=None,
         source_provider_namespace=None,
         destination_provider_name=None,
@@ -40,9 +40,14 @@ class Plan(NamespacedResource, MTV):
         warm_migration=False,
         client=None,
         teardown=True,
+        yaml_file=None,
     ):
         super().__init__(
-            name=name, namespace=namespace, client=client, teardown=teardown
+            name=name,
+            namespace=namespace,
+            client=client,
+            teardown=teardown,
+            yaml_file=yaml_file,
         )
         self.source_provider_name = source_provider_name
         self.source_provider_namespace = source_provider_namespace
@@ -60,6 +65,9 @@ class Plan(NamespacedResource, MTV):
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
+
         res.update(
             {
                 "spec": {
